# AminoLightPy
## _The best Amino.py alternative!_

Why should you choose this library?

## Features

- Improved performance
- More flexible and simpler code
- Full backwards compatibility
- Fixed many Amino.py and Amino.fix errors
- Cut out obsolete functions and ineffective parts of code

I know that many people do not want to switch to alternative libraries, 
since a huge part of the scripts are written in these libraries.

Unfortunately they are no longer supported. Therefore, I offer a better alternative.


## Installation

AminoLightPy requires [python](https://python.org/) v3.9+ to run.

Install the dependencies and start the coding.

```sh
pip install amino.light.py
```
## Development

Want to contribute? Great!


Contact me on telegram to suggest ideas!

-> @AugustLight

## API Reference
Read The Docs: [Link Here](https://aminopy.readthedocs.io/en/latest/index.html)

p.s: documentation is still up to date
## License

MIT

**Free Software, Hell Yeah!**